******************
Doc de ``classif``
******************


Voici l'autodocumentation d'un package/module

Inference
=========

.. automodule:: classif.inference
   :members:

Models
======

.. automodule:: classif.models
   :members:
